@@ -24,17 +24,17 @@ public:
     explicit Widget(QWidget *parent = 0);
     ~Widget();
 
-
 public slots:
     void GetProg (QString file);
     void showSettingsDialog();
     void loadProgs();
+    void orientationChanged(const QString& orientation);
 
 private:
     QGridLayout *layout;
 
 protected:
-    void mousePressEvent (QMouseEvent *ev);
+    void mouseReleaseEvent (QMouseEvent *ev);
     void paintEvent(QPaintEvent *event);
     bool restoreWidgetState();
 
